@@ -18,10 +18,12 @@ with open(path.join(basedir, "README.md"), encoding='utf-8') as f:
 setup(
     name="zf-school-sdk",
     author="farmer.chillax",
-    version="1.0.4",
+    version="1.1.1",
     license='MIT',
     author_email="farmer-chong@qq.com",
     description="zf School SDK for Python",
+    long_description=long_description,
+    long_description_content_type='text/markdown',
     url='https://github.com/Farmer-chong/new-school-sdk',
     packages=find_packages(),
     package_data={},
@@ -46,3 +48,6 @@ setup(
         'Topic :: Software Development :: Libraries :: Python Modules'
     ]
 )
+
+# python zf-setup.py bdist_wheel sdist
+# twine upload dist/*
\ No newline at end of file
